==> aws-cdk.aws-gamelift-1.120.0.tar.gz: package/lib/gamelift-canned-metrics.generated.d.ts <==
export declare class GameLiftMetrics {
    static activeInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static percentIdleInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static desiredInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static idleInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static maxInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static minInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
    static instanceInterruptionsSum(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            FleetId: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-gamelift-1.195.0.tar.gz: package/lib/gamelift-canned-metrics.generated.d.ts <==
export declare class GameLiftMetrics {
    static activeInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static percentIdleInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static desiredInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static idleInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static maxInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static minInstancesAverage(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
    static instanceInterruptionsSum(dimensions: {
        FleetId: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            FleetId: string;
        };
        statistic: string;
    };
}
